@@ -1,5 +1,5 @@
-causal.effect <- 
-function(y, x, z = NULL, G, expr = TRUE) {
+causal.effect <-
+function(y, x, z = NULL, G, expr = TRUE, simp = TRUE) {
   if (!is.dag(observed.graph(G))) stop("Graph 'G' is not a DAG")
   to <- topological.sort(observed.graph(G))
   to <- get.vertex.attribute(G, "name")[to]
@@ -8,7 +8,8 @@ function(y, x, z = NULL, G, expr = TRUE) {
   if (length(z) > 0) {
     if (length(setdiff(z, to)) > 0) stop("Set 'z' contains variables not present in the graph.")
   }
-  if(length(z) == 0) { 
+  res <- probability()
+  if (length(z) == 0) { 
     res <- id(y, x, probability(), G, to)
     res <- organizeTerms(res)
   } else { 
@@ -19,6 +20,12 @@ function(y, x, z = NULL, G, expr = TRUE) {
     res$fraction <- TRUE
     res$divisor <- res2
   }
-  if(expr) res <- get.expression(res)
+  if (simp) {
+    G.unobs <- unobserved.graph(G)
+    to.u <- topological.sort(G.unobs)
+    to.u <- get.vertex.attribute(G.unobs, "name")[to.u]
+    res <- simplify.expression(res, G.unobs, to.u)
+  }
+  if (expr) res <- get.expression(res)
   return(res)
-}
\ No newline at end of file
+}
